PatchSink

Struct PatchSink 

pub struct PatchSink<'a> { /* private fields */ }
Collector for patch operations.

PatchSink collects operations that will be combined into a Patch. It is used internally by StateRef types to automatically collect all state modifications.

Thread Safety

PatchSink uses a Mutex internally to support async contexts. In single-threaded usage, the lock overhead is minimal.

Implementations

Source

impl<'a> PatchSink<'a>

pub fn collect(&self, op: Op) -> TireaResult<()>

Collect an operation.