pub struct Path(/* private fields */);Expand description
A complete path into a JSON structure.
Paths are immutable sequences of segments. Use builder methods to construct paths incrementally.
Examples
use tirea_state::Path;
let path = Path::root().key("users").index(0).key("name");
assert_eq!(path.len(), 3);Implementations
Sourceimpl Path
impl Path
Sourcepub fn from_segments(segments: Vec<Seg>) -> Self
pub fn from_segments(segments: Vec<Seg>) -> Self
Create a path from a vector of segments.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a path with pre-allocated capacity.
Sourcepub fn key(self, k: impl Into<String>) -> Self
pub fn key(self, k: impl Into<String>) -> Self
Append a key segment and return self (builder pattern).
Sourcepub fn index(self, i: usize) -> Self
pub fn index(self, i: usize) -> Self
Append an index segment and return self (builder pattern).
Sourcepub fn push_index(&mut self, i: usize)
pub fn push_index(&mut self, i: usize)
Push an index segment onto the path (mutating).
Sourcepub fn segments_mut(&mut self) -> &mut Vec<Seg>
pub fn segments_mut(&mut self) -> &mut Vec<Seg>
Get a mutable reference to the segments.
Sourcepub fn with_segment(&self, seg: Seg) -> Path
pub fn with_segment(&self, seg: Seg) -> Path
Append a segment and return a new path (non-mutating builder).
Sourcepub fn is_prefix_of(&self, other: &Path) -> bool
pub fn is_prefix_of(&self, other: &Path) -> bool
Check if this path is a prefix of another path.
A path is a prefix of another if all of its segments match the beginning of the other path’s segments.
Examples
use tirea_state::path;
let parent = path!("user");
let child = path!("user", "name");
assert!(parent.is_prefix_of(&child));
assert!(!child.is_prefix_of(&parent));
assert!(parent.is_prefix_of(&parent)); // A path is a prefix of itselfSourcepub fn starts_with(&self, prefix: &Path) -> bool
pub fn starts_with(&self, prefix: &Path) -> bool
Check if this path starts with another path.