pub struct StateContext<'a> { /* private fields */ }Expand description
Pure state context with automatic patch collection.
Implementations
Sourceimpl<'a> StateContext<'a>
impl<'a> StateContext<'a>
Sourcepub fn state<T: State>(&self, path: &str) -> T::Ref<'_>
pub fn state<T: State>(&self, path: &str) -> T::Ref<'_>
Get a typed state reference at the specified path.
Sourcepub fn state_of<T: State>(&self) -> T::Ref<'_>
pub fn state_of<T: State>(&self) -> T::Ref<'_>
Get a typed state reference at the type’s canonical path.
Requires T to have #[tirea(path = "...")] set.
Panics if T::PATH is empty.
Sourcepub fn take_patch(&self) -> Patch
pub fn take_patch(&self) -> Patch
Extract collected operations as a plain patch.
Sourcepub fn take_tracked_patch(&self, source: impl Into<String>) -> TrackedPatch
pub fn take_tracked_patch(&self, source: impl Into<String>) -> TrackedPatch
Extract collected operations as a tracked patch with a source.
Sourcepub fn has_changes(&self) -> bool
pub fn has_changes(&self) -> bool
Check if any operations have been collected.